@@ -1,7 +1,7 @@
 /*
- * core-eval.c - evaluate expressions with references to internal vars
+ * SPDX-FileCopyrightText: 2012-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2012-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Evaluate expressions with references to internal vars */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -1151,6 +1153,7 @@ char *
 eval_hdata_count (const char *text, struct t_eval_context *eval_context)
 {
     struct t_hdata *hdata;
+    unsigned long ptr_value;
     void *pointer;
     char *pos1, *pos2, *value, *hdata_name, *pointer_name, str_count[64];
     int rc, count;
@@ -1181,9 +1184,10 @@ eval_hdata_count (const char *text, struct t_eval_context *eval_context)
 
     if (strncmp (pointer_name, "0x", 2) == 0)
     {
-        rc = sscanf (pointer_name, "%p", &pointer);
+        rc = sscanf (pointer_name, "%lx", &ptr_value);
         if ((rc != EOF) && (rc != 0))
         {
+            pointer = (void *)ptr_value;
             if (!hdata_check_pointer (hdata, NULL, pointer))
                 goto end;
         }
@@ -1420,6 +1424,7 @@ eval_string_hdata (const char *text, struct t_eval_context *eval_context)
     void *pointer;
     struct t_hdata *hdata;
     int rc;
+    unsigned long ptr;
 
     value = NULL;
     hdata_name = NULL;
@@ -1471,9 +1476,10 @@ eval_string_hdata (const char *text, struct t_eval_context *eval_context)
     {
         if (strncmp (pointer_name, "0x", 2) == 0)
         {
-            rc = sscanf (pointer_name, "%p", &pointer);
+            rc = sscanf (pointer_name, "%lx", &ptr);
             if ((rc != EOF) && (rc != 0))
             {
+                pointer = (void *)ptr;
                 if (!hdata_check_pointer (hdata, NULL, pointer))
                     goto end;
             }
