@@ -1,7 +1,7 @@
 /*
- * core-input.c - default input callback for buffers
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Default input callback for buffers */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -121,15 +123,6 @@ input_exec_command (struct t_gui_buffer *buffer,
         input_commands_allowed = new_commands_allowed;
     }
 
-    /* ignore spaces at the end of command */
-    pos = &command[strlen (command) - 1];
-    if (pos[0] == ' ')
-    {
-        while ((pos > command) && (pos[0] == ' '))
-            pos--;
-        pos[1] = '\0';
-    }
-
     /* extract command name */
     pos = strchr (command, ' ');
     command_name = (pos) ?
