@@ -1,10 +1,10 @@
 /*
- * core-network.c - network functions
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2005-2010 Emmanuel Bouthenot <kolter@openics.org>
+ * SPDX-FileCopyrightText: 2010 Gu1ll4um3r0m41n <aeroxteam@gmail.com>
+ * SPDX-FileCopyrightText: 2012 Simon Arlott
  *
- * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
- * Copyright (C) 2005-2010 Emmanuel Bouthenot <kolter@openics.org>
- * Copyright (C) 2010 Gu1ll4um3r0m41n <aeroxteam@gmail.com>
- * Copyright (C) 2012 Simon Arlott
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -22,17 +22,12 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Network functions */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-/* _XPG4_2 is needed on SunOS for macros like CMSG_SPACE */
-/* __EXTENSIONS__ is needed on SunOS for constants like NI_MAXHOST */
-#ifdef __sun
-#define _XPG4_2
-#define __EXTENSIONS__
-#endif
-
 #include <unistd.h>
 #include <fcntl.h>
 #include <stdlib.h>
