@@ -1,5 +1,7 @@
 /*
- * Copyright (C) 2013-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2013-2025 Sébastien Helleu <flashcode@flashtux.org>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -31,9 +33,9 @@ extern struct t_config_option *secure_config_crypt_hash_algo;
 extern struct t_config_option *secure_config_crypt_passphrase_command;
 extern struct t_config_option *secure_config_crypt_salt;
 
-extern int secure_config_read ();
-extern int secure_config_write ();
-extern int secure_config_init ();
-extern void secure_config_free ();
+extern int secure_config_read (void);
+extern int secure_config_write (void);
+extern int secure_config_init (void);
+extern void secure_config_free (void);
 
 #endif /* WEECHAT_SECURE_CONFIG_H */
