@@ -1,7 +1,7 @@
 /*
- * core-util.c - some useful functions
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Some useful functions */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -166,6 +168,8 @@ util_get_time_string (const time_t *date)
 /*
  * Formats date and time like strftime (but with timeval structure as input)
  * and adds extra specifiers:
+ *   - "%@": return the date expressed in Coordinated Universal Time (UTC)
+ *           instead of date relative to the user's specified timezone
  *   - "%.1" to "%.6": first N digits of microseconds, zero-padded
  *   - "%f": alias of "%.6" (microseconds, zero-padded to 6 digits)
  *   - "%!": timestamp as integer, in seconds (value of tv->tv_sec)
@@ -176,14 +180,15 @@ util_strftimeval (char *string, int max, const char *format, struct timeval *tv)
 {
     char **format2, str_temp[32];
     const char *ptr_format;
-    struct tm *local_time;
-    int length, bytes;
+    struct tm *date_time;
+    int length, bytes, local_time;
     long usec;
 
     if (!string || (max <= 0) || !format || !tv)
         return 0;
 
     string[0] = '\0';
+    local_time = 1;
 
     if (!format[0])
         return 0;
@@ -206,6 +211,11 @@ util_strftimeval (char *string, int max, const char *format, struct timeval *tv)
             string_dyn_concat (format2, "%%", -1);
             ptr_format += 2;
         }
+        else if ((ptr_format[0] == '%') && (ptr_format[1] == '@'))
+        {
+            local_time = 0;
+            ptr_format += 2;
+        }
         else if ((ptr_format[0] == '%') && (ptr_format[1] == '.'))
         {
             if ((ptr_format[2] >= '1') && (ptr_format[2] <= '6'))
@@ -242,14 +252,17 @@ util_strftimeval (char *string, int max, const char *format, struct timeval *tv)
         }
     }
 
-    local_time = localtime (&(tv->tv_sec));
-    if (!local_time)
+    if (local_time)
+        date_time = localtime (&(tv->tv_sec));
+    else
+        date_time = gmtime (&(tv->tv_sec));
+    if (!date_time)
     {
         string_dyn_free (format2, 1);
         return 0;
     }
 
-    bytes = strftime (string, max, *format2, local_time);
+    bytes = strftime (string, max, *format2, date_time);
 
     string_dyn_free (format2, 1);
 
@@ -628,13 +641,13 @@ util_parse_delay (const char *string_delay, unsigned long long default_factor,
  *   "0.3.0"     ==> 196608   (== 0x00030000)
  */
 
-int
+unsigned long
 util_version_number (const char *version)
 {
     char **items, buf[64], *error;
     const char *ptr_item;
-    int num_items, i, version_int[4], index_buf;
-    long number;
+    int num_items, i, index_buf;
+    unsigned long number, values[4];
 
     if (!version || !version[0])
         return 0;
@@ -646,7 +659,7 @@ util_version_number (const char *version)
                           4, &num_items);
     for (i = 0; i < 4; i++)
     {
-        version_int[i] = 0;
+        values[i] = 0;
         if (items && (i < num_items))
         {
             ptr_item = items[i];
@@ -666,22 +679,18 @@ util_version_number (const char *version)
             if (buf[0])
             {
                 error = NULL;
-                number = strtol (buf, &error, 10);
+                number = strtoul (buf, &error, 10);
                 if (error && !error[0])
                 {
-                    if (number < 0)
-                        number = 0;
-                    else if ((i == 0) && (number > 0x7F))
-                        number = 0x7F;
-                    else if ((i > 0) && (number > 0xFF))
+                    if (number > 0xFF)
                         number = 0xFF;
-                    version_int[i] = number;
+                    values[i] = number;
                 }
             }
         }
     }
     string_free_split (items);
 
-    return (version_int[0] << 24) | (version_int[1] << 16)
-        | (version_int[2] << 8) | version_int[3];
+    return (values[0] << 24) | (values[1] << 16)
+        | (values[2] << 8) | values[3];
 }
