@@ -1,7 +1,7 @@
 /*
- * hook-process.c - WeeChat process hook
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* WeeChat process hook */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -277,7 +279,9 @@ hook_process_child (struct t_hook *hook_process)
         }
         rc = weeurl_download (ptr_url,
                               HOOK_PROCESS(hook_process, options),
-                              NULL);  /* output */
+                              0,  /* timeout */
+                              NULL,  /* output */
+                              NULL);  /* stop_download */
     }
     else if (strncmp (HOOK_PROCESS(hook_process, command), "func:", 5) == 0)
     {
