@@ -1,5 +1,7 @@
 /*
- * Copyright (C) 2023-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2023-2025 Sébastien Helleu <flashcode@flashtux.org>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -20,6 +22,8 @@
 #ifndef WEECHAT_HOOK_URL_H
 #define WEECHAT_HOOK_URL_H
 
+#include <pthread.h>
+
 struct t_weechat_plugin;
 struct t_infolist_item;
 struct t_hashtable;
@@ -37,6 +41,7 @@ struct t_hook_url
     char *url;                         /* URL                               */
     struct t_hashtable *options;       /* URL options (see doc)             */
     long timeout;                      /* timeout (ms) (0 = no timeout)     */
+    int stop_transfer;                 /* 1 is used to stop transfer now    */
     pthread_t thread_id;               /* thread id                         */
     int thread_created;                /* thread created                    */
     int thread_running;                /* 1 if thread is running            */
