@@ -1,8 +1,8 @@
 /*
- * gui-history.c - memorize commands or text for buffers (used by all GUI)
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2005 Emmanuel Bouthenot <kolter@openics.org>
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
- * Copyright (C) 2005 Emmanuel Bouthenot <kolter@openics.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -20,6 +20,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Memorize commands or text for buffers (used by all GUI) */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -118,7 +120,7 @@ gui_history_buffer_add (struct t_gui_buffer *buffer, const char *string)
  */
 
 void
-gui_history_global_remove_oldest ()
+gui_history_global_remove_oldest (void)
 {
     struct t_gui_buffer *ptr_buffer;
     struct t_gui_history *ptr_history;
@@ -300,7 +302,7 @@ gui_history_search (struct t_gui_buffer *buffer,
  */
 
 void
-gui_history_global_free ()
+gui_history_global_free (void)
 {
     struct t_gui_history *ptr_history;
 
@@ -356,6 +358,7 @@ gui_history_hdata_history_update_cb (void *data,
     struct t_gui_history *ptr_history;
     struct t_gui_buffer *ptr_buffer;
     const char *text, *buffer;
+    unsigned long value;
     int rc;
 
     /* make C compiler happy */
@@ -384,9 +387,9 @@ gui_history_hdata_history_update_cb (void *data,
             buffer = hashtable_get (hashtable, "buffer");
             if (buffer)
             {
-                rc = sscanf (buffer, "%p", &ptr_buffer);
-                if ((rc == EOF) || (rc == 0))
-                    ptr_buffer = NULL;
+                rc = sscanf (buffer, "%lx", &value);
+                if ((rc != EOF) && (rc != 0))
+                    ptr_buffer = (struct t_gui_buffer *)value;
             }
         }
         if (ptr_buffer)
