@@ -1,7 +1,7 @@
 /*
- * gui-line.c - line functions (used by all GUI)
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Line functions (used by all GUI) */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -1671,6 +1673,7 @@ gui_line_hook_update (struct t_gui_line *line,
 {
     const char *ptr_value, *ptr_value2;
     struct t_gui_buffer *ptr_buffer;
+    unsigned long value_pointer;
     long value;
     char *error, *new_message, *pos_newline;
     int rc, tags_updated, notify_level_updated, highlight_updated;
@@ -1704,7 +1707,8 @@ gui_line_hook_update (struct t_gui_line *line,
             {
                 if ((ptr_value2[0] == '0') && (ptr_value2[1] == 'x'))
                 {
-                    rc = sscanf (ptr_value2, "%p", &ptr_buffer);
+                    rc = sscanf (ptr_value2 + 2, "%lx", &value_pointer);
+                    ptr_buffer = (struct t_gui_buffer *)value_pointer;
                     if ((rc != EOF) && (rc >= 1)
                         && gui_chat_buffer_valid (ptr_buffer, line->data->buffer->type))
                     {
