@@ -1,5 +1,7 @@
 /*
- * Copyright (C) 2013-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2013-2025 Sébastien Helleu <flashcode@flashtux.org>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -20,6 +22,6 @@
 #ifndef WEECHAT_PLUGIN_ALIAS_COMPLETION_H
 #define WEECHAT_PLUGIN_ALIAS_COMPLETION_H
 
-extern void alias_completion_init ();
+extern void alias_completion_init (void);
 
 #endif /* WEECHAT_PLUGIN_ALIAS_COMPLETION_H */
