@@ -1,7 +1,7 @@
 /*
- * buflist.c - Bar with list of buffers
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Bar with list of buffers */
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -56,7 +58,7 @@ struct t_hdata *buflist_hdata_bar_window = NULL;
  */
 
 void
-buflist_add_bar ()
+buflist_add_bar (void)
 {
     weechat_bar_new (
         BUFLIST_BAR_NAME,
@@ -534,5 +536,12 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
     buflist_config_write ();
     buflist_config_free ();
 
+    buflist_hdata_window = NULL;
+    buflist_hdata_buffer = NULL;
+    buflist_hdata_hotlist = NULL;
+    buflist_hdata_bar = NULL;
+    buflist_hdata_bar_item = NULL;
+    buflist_hdata_bar_window = NULL;
+
     return WEECHAT_RC_OK;
 }
