@@ -1,5 +1,7 @@
 /*
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -29,7 +31,7 @@ extern int fifo_quiet;
 extern int fifo_fd;
 extern char *fifo_filename;
 
-extern void fifo_create ();
-extern void fifo_remove ();
+extern void fifo_create (void);
+extern void fifo_remove (void);
 
 #endif /* WEECHAT_PLUGIN_FIFO_H */
