@@ -1,7 +1,7 @@
 /*
- * irc-bar-item.c - bar items for IRC plugin
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Bar items for IRC plugin */
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -543,7 +545,6 @@ irc_bar_item_nick_modes (const void *pointer, void *data,
 {
     struct t_irc_server *server;
     char *buf;
-    int length;
 
     /* make C compiler happy */
     (void) pointer;
@@ -559,14 +560,9 @@ irc_bar_item_nick_modes (const void *pointer, void *data,
     if (!server || !server->nick_modes || !server->nick_modes[0])
         return NULL;
 
-    length = 64 + strlen (server->nick_modes) + 1;
-    buf = malloc (length);
-    if (buf)
-    {
-        snprintf (buf, length, "%s%s",
-                  IRC_COLOR_ITEM_NICK_MODES,
-                  server->nick_modes);
-    }
+    weechat_asprintf (&buf,
+                      "%s%s",
+                      IRC_COLOR_ITEM_NICK_MODES, server->nick_modes);
 
     return buf;
 }
@@ -630,6 +626,7 @@ struct t_hashtable *
 irc_bar_item_focus_buffer_nicklist (const void *pointer, void *data,
                                     struct t_hashtable *info)
 {
+    unsigned long value;
     int rc;
     struct t_gui_buffer *buffer;
     struct t_irc_nick *ptr_nick;
@@ -640,10 +637,12 @@ irc_bar_item_focus_buffer_nicklist (const void *pointer, void *data,
     if (!str_buffer || !str_buffer[0])
         return NULL;
 
-    rc = sscanf (str_buffer, "%p", &buffer);
+    rc = sscanf (str_buffer, "%lx", &value);
     if ((rc == EOF) || (rc == 0))
         return NULL;
 
+    buffer = (struct t_gui_buffer *)value;
+
     IRC_BUFFER_GET_SERVER_CHANNEL(buffer);
 
     /* make C compiler happy */
@@ -710,7 +709,7 @@ irc_bar_item_buffer_switch (const void *pointer, void *data,
  */
 
 void
-irc_bar_item_update_channel ()
+irc_bar_item_update_channel (void)
 {
     weechat_bar_item_update ("buffer_name");
     weechat_bar_item_update ("buffer_short_name");
@@ -722,7 +721,7 @@ irc_bar_item_update_channel ()
  */
 
 void
-irc_bar_item_init ()
+irc_bar_item_init (void)
 {
     weechat_bar_item_new ("buffer_plugin",
                           &irc_bar_item_buffer_plugin, NULL, NULL);
