@@ -1,7 +1,7 @@
 /*
- * irc-raw.c - functions for IRC raw data messages
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Functions for IRC raw data messages */
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -315,7 +317,7 @@ irc_raw_message_print (struct t_irc_raw_message *raw_message)
  */
 
 void
-irc_raw_set_localvar_filter ()
+irc_raw_set_localvar_filter (void)
 {
     if (!irc_raw_buffer)
         return;
@@ -329,7 +331,7 @@ irc_raw_set_localvar_filter ()
  */
 
 void
-irc_raw_set_title ()
+irc_raw_set_title (void)
 {
     char str_title[1024];
 
@@ -490,7 +492,7 @@ irc_raw_message_free (struct t_irc_raw_message *raw_message)
  */
 
 void
-irc_raw_message_free_all ()
+irc_raw_message_free_all (void)
 {
     while (irc_raw_messages)
     {
@@ -503,7 +505,7 @@ irc_raw_message_free_all ()
  */
 
 void
-irc_raw_message_remove_old ()
+irc_raw_message_remove_old (void)
 {
     int max_messages;
 
@@ -643,7 +645,7 @@ irc_raw_add_to_infolist (struct t_infolist *infolist,
  */
 
 void
-irc_raw_init ()
+irc_raw_init (void)
 {
     irc_raw_filter_hashtable_options = weechat_hashtable_new (
         8,
@@ -662,7 +664,7 @@ irc_raw_init ()
  */
 
 void
-irc_raw_end ()
+irc_raw_end (void)
 {
     irc_raw_message_free_all ();
 
