@@ -1,7 +1,7 @@
 /*
- * irc-upgrade.c - save/restore IRC plugin data when upgrading WeeChat
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Save/restore IRC plugin data when upgrading WeeChat */
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -293,7 +295,7 @@ irc_upgrade_save (int force_disconnected_state)
  */
 
 void
-irc_upgrade_set_buffer_callbacks ()
+irc_upgrade_set_buffer_callbacks (void)
 {
     struct t_infolist *infolist;
     struct t_gui_buffer *ptr_buffer;
@@ -990,7 +992,7 @@ irc_upgrade_read_cb (const void *pointer, void *data,
  */
 
 void
-irc_upgrade_set_buffer_properties ()
+irc_upgrade_set_buffer_properties (void)
 {
     struct t_irc_server *ptr_server;
     struct t_irc_channel *ptr_channel;
@@ -1021,7 +1023,7 @@ irc_upgrade_set_buffer_properties ()
  */
 
 int
-irc_upgrade_load ()
+irc_upgrade_load (void)
 {
     int rc;
     struct t_upgrade_file *upgrade_file;
