@@ -1,7 +1,7 @@
 /*
- * logger-info.c - info and infolist hooks for logger plugin
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Info and infolist hooks for logger plugin */
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -38,6 +40,7 @@ logger_info_log_file_cb (const void *pointer, void *data,
                          const char *arguments)
 {
     int rc;
+    unsigned long value;
     struct t_gui_buffer *buffer;
     struct t_logger_buffer *logger_buffer;
 
@@ -52,20 +55,16 @@ logger_info_log_file_cb (const void *pointer, void *data,
     buffer = NULL;
     if (strncmp (arguments, "0x", 2) == 0)
     {
-        rc = sscanf (arguments, "%p", &buffer);
-        if ((rc != EOF) && (rc != 0) && buffer)
+        rc = sscanf (arguments, "%lx", &value);
+        if ((rc != EOF) && (rc != 0) && value)
         {
-            if (!weechat_hdata_check_pointer (weechat_hdata_get ("buffer"),
-                                              NULL,
-                                              buffer))
+            if (weechat_hdata_check_pointer (weechat_hdata_get ("buffer"),
+                                             NULL,
+                                             (struct t_gui_buffer *)value))
             {
-                buffer = NULL;
+                buffer = (struct t_gui_buffer *)value;
             }
         }
-        else
-        {
-            buffer = NULL;
-        }
     }
     else
     {
