@@ -1,8 +1,8 @@
 /*
- * weechat-lua.c - lua plugin for WeeChat
+ * SPDX-FileCopyrightText: 2006-2007 Emmanuel Bouthenot <kolter@openics.org>
+ * SPDX-FileCopyrightText: 2006-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2006-2007 Emmanuel Bouthenot <kolter@openics.org>
- * Copyright (C) 2006-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -20,6 +20,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Lua plugin for WeeChat */
+
 #undef _
 
 #include <lua.h>
@@ -186,11 +188,10 @@ weechat_lua_tohashtable (lua_State *interpreter, int index, int size,
  */
 
 void
-weechat_lua_output_flush ()
+weechat_lua_output_flush (void)
 {
     const char *ptr_command;
     char *temp_buffer, *command;
-    int length;
 
     if (!(*lua_buffer_output)[0])
         return;
@@ -219,12 +220,11 @@ weechat_lua_output_flush ()
             }
             else
             {
-                length = 1 + strlen (temp_buffer) + 1;
-                command = malloc (length);
-                if (command)
+                if (weechat_asprintf (&command,
+                                      "%c%s",
+                                      temp_buffer[0],
+                                      temp_buffer) >= 0)
                 {
-                    snprintf (command, length, "%c%s",
-                              temp_buffer[0], temp_buffer);
                     weechat_command (lua_eval_buffer,
                                      (command[0]) ? command : " ");
                     free (command);
@@ -840,7 +840,7 @@ weechat_lua_reload_name (const char *name)
  */
 
 void
-weechat_lua_unload_all ()
+weechat_lua_unload_all (void)
 {
     while (lua_scripts)
     {
