@@ -1,7 +1,7 @@
 /*
- * plugin.c - WeeChat plugins management (load/unload dynamic C libraries)
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* WeeChat plugins management (load/unload dynamic C libraries) */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -691,6 +693,7 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->file_get_content = &dir_file_get_content;
         new_plugin->file_copy = &dir_file_copy;
         new_plugin->file_compress = &dir_file_compress;
+        new_plugin->file_compare = &dir_file_compare;
 
         new_plugin->util_timeval_cmp = &util_timeval_cmp;
         new_plugin->util_timeval_diff = &util_timeval_diff;
@@ -888,6 +891,7 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->completion_new = &gui_completion_new;
         new_plugin->completion_search = &gui_completion_search;
         new_plugin->completion_get_string = &gui_completion_get_string;
+        new_plugin->completion_set = &gui_completion_set;
         new_plugin->completion_list_add = &gui_completion_list_add;
         new_plugin->completion_free = &gui_completion_free;
 
@@ -1053,7 +1057,7 @@ plugin_auto_load (char *force_plugin_autoload,
     struct t_plugin_args plugin_args;
     struct t_arraylist *arraylist;
     struct t_hashtable *options;
-    int length, i;
+    int i;
 
     plugin_args.argc = argc;
     plugin_args.argv = argv;
@@ -1106,23 +1110,20 @@ plugin_auto_load (char *force_plugin_autoload,
         extra_libdir = getenv (WEECHAT_EXTRA_LIBDIR);
         if (extra_libdir && extra_libdir[0])
         {
-            length = strlen (extra_libdir) + 16 + 1;
-            dir_name = malloc (length);
-            snprintf (dir_name, length, "%s/plugins", extra_libdir);
-            dir_exec_on_files (dir_name, 1, 0,
-                               &plugin_auto_load_file, &plugin_args);
-            free (dir_name);
+            if (string_asprintf (&dir_name, "%s/plugins", extra_libdir) >= 0)
+            {
+                dir_exec_on_files (dir_name, 1, 0,
+                                   &plugin_auto_load_file, &plugin_args);
+                free (dir_name);
+            }
         }
     }
 
     /* auto-load plugins in WeeChat global lib dir */
     if (load_from_lib_dir)
     {
-        length = strlen (WEECHAT_LIBDIR) + 16 + 1;
-        dir_name = malloc (length);
-        if (dir_name)
+        if (string_asprintf (&dir_name,"%s/plugins", WEECHAT_LIBDIR) >= 0)
         {
-            snprintf (dir_name, length, "%s/plugins", WEECHAT_LIBDIR);
             dir_exec_on_files (dir_name, 1, 0,
                                &plugin_auto_load_file, &plugin_args);
             free (dir_name);
@@ -1297,7 +1298,7 @@ plugin_unload_name (const char *name)
  */
 
 void
-plugin_unload_all ()
+plugin_unload_all (void)
 {
     int plugins_loaded;
 
@@ -1351,50 +1352,45 @@ plugin_reload_name (const char *name, int argc, char **argv)
  */
 
 void
-plugin_display_short_list ()
+plugin_display_short_list (void)
 {
-    const char *plugins_loaded;
-    char *buf;
-    int length;
+    char **buf;
     struct t_weechat_plugin *ptr_plugin;
     struct t_weelist *list;
     struct t_weelist_item *ptr_item;
 
-    if (weechat_plugins)
+    if (!weechat_plugins)
+        return;
+
+    list = weelist_new ();
+    if (!list)
+        return;
+
+    for (ptr_plugin = weechat_plugins; ptr_plugin;
+         ptr_plugin = ptr_plugin->next_plugin)
     {
-        list = weelist_new ();
-        if (list)
-        {
-            plugins_loaded = _("Plugins loaded:");
-
-            length = strlen (plugins_loaded) + 1;
-
-            for (ptr_plugin = weechat_plugins; ptr_plugin;
-                 ptr_plugin = ptr_plugin->next_plugin)
-            {
-                length += strlen (ptr_plugin->name) + 2;
-                weelist_add (list, ptr_plugin->name, WEECHAT_LIST_POS_SORT, NULL);
-            }
-            length++;
-
-            buf = malloc (length);
-            if (buf)
-            {
-                strcpy (buf, plugins_loaded);
-                strcat (buf, " ");
-                for (ptr_item = list->items; ptr_item;
-                     ptr_item = ptr_item->next_item)
-                {
-                    strcat (buf, ptr_item->data);
-                    if (ptr_item->next_item)
-                        strcat (buf, ", ");
-                }
-                gui_chat_printf (NULL, "%s", buf);
-                free (buf);
-            }
-            weelist_free (list);
-        }
+        weelist_add (list, ptr_plugin->name, WEECHAT_LIST_POS_SORT, NULL);
     }
+
+    buf = string_dyn_alloc (256);
+    if (!buf)
+    {
+        weelist_free (list);
+        return;
+    }
+
+    string_dyn_concat (buf, _("Plugins loaded:"), -1);
+    string_dyn_concat (buf, " ", -1);
+    for (ptr_item = list->items; ptr_item; ptr_item = ptr_item->next_item)
+    {
+        string_dyn_concat (buf, ptr_item->data, -1);
+        if (ptr_item->next_item)
+            string_dyn_concat (buf, ", ", -1);
+    }
+    gui_chat_printf (NULL, "%s", *buf);
+
+    string_dyn_free (buf, 1);
+    weelist_free (list);
 }
 
 /*
@@ -1420,7 +1416,7 @@ plugin_init (char *force_plugin_autoload, int argc, char *argv[])
  */
 
 void
-plugin_end ()
+plugin_end (void)
 {
     /* write plugins configuration options */
     plugin_config_write ();
@@ -1536,7 +1532,7 @@ plugin_add_to_infolist (struct t_infolist *infolist,
  */
 
 void
-plugin_print_log ()
+plugin_print_log (void)
 {
     struct t_weechat_plugin *ptr_plugin;
 
