@@ -1,7 +1,7 @@
 /*
- * relay-api-protocol.c - API protocol for relay to client
+ * SPDX-FileCopyrightText: 2023-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2023-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* API protocol for relay to client */
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -372,7 +374,7 @@ RELAY_API_PROTOCOL_CALLBACK(options)
     relay_api_msg_send_json (
         client,
         RELAY_HTTP_204_NO_CONTENT,
-        "Access-Control-Allow-Methods: GET, POST, PUT, DELETE\r\n"
+        "Access-Control-Allow-Methods: " RELAY_API_ALLOWED_METHODS "\r\n"
         "Access-Control-Allow-Headers: origin, content-type, accept, authorization",
         NULL,  /* body_type */
         NULL);  /* json_body */
@@ -399,9 +401,13 @@ RELAY_API_PROTOCOL_CALLBACK(handshake)
     json_body = cJSON_Parse (client->http_req->body);
     if (json_body)
     {
+        if (!cJSON_IsObject (json_body))
+            return RELAY_API_PROTOCOL_RC_BAD_REQUEST;
         json_algos = cJSON_GetObjectItem (json_body, "password_hash_algo");
         if (json_algos)
         {
+            if (!cJSON_IsArray (json_algos))
+                goto invalid_hash_algo;
             cJSON_ArrayForEach (json_algo, json_algos)
             {
                 ptr_algo = (cJSON_IsString (json_algo)) ?
@@ -409,7 +415,17 @@ RELAY_API_PROTOCOL_CALLBACK(handshake)
                 if (ptr_algo)
                 {
                     index_hash_algo = relay_auth_password_hash_algo_search (ptr_algo);
-                    if ((index_hash_algo >= 0) && (index_hash_algo > hash_algo_found))
+                    if (index_hash_algo < 0)
+                    {
+                        relay_api_msg_send_error_json (
+                            client,
+                            RELAY_HTTP_400_BAD_REQUEST, NULL,
+                            "Hash algorithm \"%s\" not found",
+                            ptr_algo);
+                        cJSON_Delete (json_body);
+                        return RELAY_API_PROTOCOL_RC_OK;
+                    }
+                    if (index_hash_algo > hash_algo_found)
                     {
                         if (weechat_string_match_list (
                                 relay_auth_password_hash_algo_name[index_hash_algo],
@@ -420,6 +436,8 @@ RELAY_API_PROTOCOL_CALLBACK(handshake)
                         }
                     }
                 }
+                else
+                    goto invalid_hash_algo;
             }
         }
     }
@@ -458,6 +476,14 @@ RELAY_API_PROTOCOL_CALLBACK(handshake)
         cJSON_Delete (json_body);
 
     return RELAY_API_PROTOCOL_RC_OK;
+
+invalid_hash_algo:
+    relay_api_msg_send_error_json (
+        client,
+        RELAY_HTTP_400_BAD_REQUEST, NULL,
+        "Invalid hash algorithm");
+    cJSON_Delete (json_body);
+    return RELAY_API_PROTOCOL_RC_OK;
 }
 
 /*
@@ -710,57 +736,55 @@ RELAY_API_PROTOCOL_CALLBACK(input)
     char str_delay[32];
 
     json_body = cJSON_Parse (client->http_req->body);
-    if (!json_body)
+    if (!json_body || !cJSON_IsObject (json_body))
         return RELAY_API_PROTOCOL_RC_BAD_REQUEST;
 
-    /* get buffer either by id or by name */
+    /* get buffer either by name or by id */
     ptr_buffer = NULL;
-    json_buffer_id = cJSON_GetObjectItem (json_body, "buffer_id");
-    if (json_buffer_id)
+    json_buffer_name = cJSON_GetObjectItem (json_body, "buffer_name");
+    if (json_buffer_name)
     {
-        if (cJSON_IsNumber (json_buffer_id))
+        if (cJSON_IsString (json_buffer_name))
         {
-            snprintf (str_id, sizeof (str_id),
-                      "%lld", (long long)cJSON_GetNumberValue (json_buffer_id));
-            ptr_buffer = weechat_buffer_search ("==id", str_id);
+            ptr_buffer_name = cJSON_GetStringValue (json_buffer_name);
+            ptr_buffer = weechat_buffer_search ("==", ptr_buffer_name);
             if (!ptr_buffer)
             {
                 relay_api_msg_send_error_json (
                     client,
                     RELAY_HTTP_400_BAD_REQUEST, NULL,
-                    "Buffer \"%lld\" not found",
-                    (long long)cJSON_GetNumberValue (json_buffer_id));
+                    "Buffer \"%s\" not found",
+                    ptr_buffer_name);
                 cJSON_Delete (json_body);
                 return RELAY_API_PROTOCOL_RC_OK;
             }
         }
     }
-    else
+    if (!ptr_buffer)
     {
-        json_buffer_name = cJSON_GetObjectItem (json_body, "buffer_name");
-        if (json_buffer_name)
+        json_buffer_id = cJSON_GetObjectItem (json_body, "buffer_id");
+        if (json_buffer_id)
         {
-            if (cJSON_IsString (json_buffer_name))
+            if (cJSON_IsNumber (json_buffer_id))
             {
-                ptr_buffer_name = cJSON_GetStringValue (json_buffer_name);
-                ptr_buffer = weechat_buffer_search ("==", ptr_buffer_name);
+                snprintf (str_id, sizeof (str_id),
+                          "%lld", (long long)cJSON_GetNumberValue (json_buffer_id));
+                ptr_buffer = weechat_buffer_search ("==id", str_id);
                 if (!ptr_buffer)
                 {
                     relay_api_msg_send_error_json (
                         client,
                         RELAY_HTTP_400_BAD_REQUEST, NULL,
-                        "Buffer \"%s\" not found",
-                        ptr_buffer_name);
+                        "Buffer \"%lld\" not found",
+                        (long long)cJSON_GetNumberValue (json_buffer_id));
                     cJSON_Delete (json_body);
                     return RELAY_API_PROTOCOL_RC_OK;
                 }
             }
         }
-        else
-        {
-            ptr_buffer = weechat_buffer_search_main ();
-        }
     }
+    if (!ptr_buffer)
+        ptr_buffer = weechat_buffer_search_main ();
     if (!ptr_buffer)
     {
         cJSON_Delete (json_body);
@@ -839,57 +863,55 @@ RELAY_API_PROTOCOL_CALLBACK(completion)
     struct t_gui_buffer *ptr_buffer;
 
     json_body = cJSON_Parse (client->http_req->body);
-    if (!json_body)
+    if (!json_body || !cJSON_IsObject(json_body))
         return RELAY_API_PROTOCOL_RC_BAD_REQUEST;
 
-    /* get buffer either by id or by name */
+    /* get buffer either by name or by id */
     ptr_buffer = NULL;
-    json_buffer_id = cJSON_GetObjectItem (json_body, "buffer_id");
-    if (json_buffer_id)
+    json_buffer_name = cJSON_GetObjectItem (json_body, "buffer_name");
+    if (json_buffer_name)
     {
-        if (cJSON_IsNumber (json_buffer_id))
+        if (cJSON_IsString (json_buffer_name))
         {
-            snprintf (str_id, sizeof(str_id),
-                      "%lld", (long long)cJSON_GetNumberValue (json_buffer_id));
-            ptr_buffer = weechat_buffer_search ("==id", str_id);
+            ptr_buffer_name = cJSON_GetStringValue (json_buffer_name);
+            ptr_buffer = weechat_buffer_search ("==", ptr_buffer_name);
             if (!ptr_buffer)
             {
                 relay_api_msg_send_error_json (
                     client,
                     RELAY_HTTP_400_BAD_REQUEST, NULL,
-                    "Buffer \"%lld\" not found",
-                    (long long)cJSON_GetNumberValue (json_buffer_id));
+                    "Buffer \"%s\" not found",
+                    ptr_buffer_name);
                 cJSON_Delete (json_body);
                 return RELAY_API_PROTOCOL_RC_OK;
             }
         }
     }
-    else
+    if (!ptr_buffer)
     {
-        json_buffer_name = cJSON_GetObjectItem (json_body, "buffer_name");
-        if (json_buffer_name)
+        json_buffer_id = cJSON_GetObjectItem (json_body, "buffer_id");
+        if (json_buffer_id)
         {
-            if (cJSON_IsString (json_buffer_name))
+            if (cJSON_IsNumber (json_buffer_id))
             {
-                ptr_buffer_name = cJSON_GetStringValue (json_buffer_name);
-                ptr_buffer = weechat_buffer_search ("==", ptr_buffer_name);
+                snprintf (str_id, sizeof(str_id),
+                          "%lld", (long long)cJSON_GetNumberValue (json_buffer_id));
+                ptr_buffer = weechat_buffer_search ("==id", str_id);
                 if (!ptr_buffer)
                 {
                     relay_api_msg_send_error_json (
                         client,
                         RELAY_HTTP_400_BAD_REQUEST, NULL,
-                        "Buffer \"%s\" not found",
-                        ptr_buffer_name);
+                        "Buffer \"%lld\" not found",
+                        (long long)cJSON_GetNumberValue (json_buffer_id));
                     cJSON_Delete (json_body);
                     return RELAY_API_PROTOCOL_RC_OK;
                 }
             }
         }
-        else
-        {
-            ptr_buffer = weechat_buffer_search_main ();
-        }
     }
+    if (!ptr_buffer)
+        ptr_buffer = weechat_buffer_search_main ();
     if (!ptr_buffer)
     {
         cJSON_Delete (json_body);
@@ -1195,7 +1217,7 @@ relay_api_protocol_recv_json (struct t_relay_client *client, const char *json)
 void
 relay_api_protocol_recv_http (struct t_relay_client *client)
 {
-    int i, num_args;
+    int i, num_args, match_method, match_resource;
     char str_error[1024];
     enum t_relay_api_protocol_rc return_code;
     struct t_relay_api_protocol_cb protocol_cb[] = {
@@ -1236,18 +1258,22 @@ relay_api_protocol_recv_http (struct t_relay_client *client)
         || !client->http_req->path_items[1]
         || (strcmp (client->http_req->path_items[0], "api") != 0))
     {
-        goto error_not_found;
+        goto resource_not_found;
     }
 
     num_args = client->http_req->num_path_items - 2;
 
     for (i = 0; protocol_cb[i].resource; i++)
     {
-        if (strcmp (protocol_cb[i].method, client->http_req->method) != 0)
-            continue;
+        match_method = (strcmp (protocol_cb[i].method, client->http_req->method) == 0);
 
-        if ((strcmp (protocol_cb[i].resource, "*") != 0)
-            && (strcmp (protocol_cb[i].resource, client->http_req->path_items[1]) != 0))
+        match_resource = ((strcmp (protocol_cb[i].resource, "*") == 0)
+                          || (strcmp (protocol_cb[i].resource, client->http_req->path_items[1]) == 0));
+
+        if (!match_method && (strcmp (protocol_cb[i].resource, "*") != 0) && match_resource)
+            goto error_method_not_allowed;
+
+        if (!match_method || !match_resource)
             continue;
 
         if (protocol_cb[i].auth_required
@@ -1329,7 +1355,19 @@ relay_api_protocol_recv_http (struct t_relay_client *client)
         }
     }
 
-    goto error_not_found;
+resource_not_found:
+    if (!client->http_req->method
+        || ((strcmp (client->http_req->method, "GET") != 0)
+            && (strcmp (client->http_req->method, "POST") != 0)
+            && (strcmp (client->http_req->method, "PUT") != 0)
+            && (strcmp (client->http_req->method, "DELETE") != 0)))
+    {
+        goto error_method_not_allowed;
+    }
+    else
+    {
+        goto error_not_found;
+    }
 
 error_bad_request:
     relay_api_msg_send_error_json (client, RELAY_HTTP_400_BAD_REQUEST,
@@ -1341,6 +1379,12 @@ error_not_found:
                                    NULL, RELAY_HTTP_ERROR_NOT_FOUND);
     goto error;
 
+error_method_not_allowed:
+    relay_api_msg_send_error_json (client, RELAY_HTTP_405_METHOD_NOT_ALLOWED,
+                                   "Allow: " RELAY_API_ALLOWED_METHODS,
+                                   RELAY_HTTP_ERROR_METHOD_NOT_ALLOWED);
+    goto error;
+
 error_memory:
     relay_api_msg_send_error_json (client, RELAY_HTTP_503_SERVICE_UNAVAILABLE,
                                    NULL, RELAY_HTTP_ERROR_OUT_OF_MEMORY);
@@ -1349,15 +1393,28 @@ error_memory:
 error:
     if (weechat_relay_plugin->debug >= 1)
     {
-        weechat_printf (NULL,
-                        _("%s%s: failed to execute route \"%s %s\" "
-                          "for client %s%s%s"),
-                        weechat_prefix ("error"),
-                        RELAY_PLUGIN_NAME,
-                        client->http_req->method,
-                        client->http_req->path,
-                        RELAY_COLOR_CHAT_CLIENT,
-                        client->desc,
-                        RELAY_COLOR_CHAT);
+        if (client->http_req->method && client->http_req->path)
+        {
+            weechat_printf (NULL,
+                            _("%s%s: failed to execute route \"%s %s\" "
+                              "for client %s%s%s"),
+                            weechat_prefix ("error"),
+                            RELAY_PLUGIN_NAME,
+                            client->http_req->method,
+                            client->http_req->path,
+                            RELAY_COLOR_CHAT_CLIENT,
+                            client->desc,
+                            RELAY_COLOR_CHAT);
+        }
+        else
+        {
+            weechat_printf (NULL,
+                            _("%s%s: invalid data received from client %s%s%s"),
+                            weechat_prefix ("error"),
+                            RELAY_PLUGIN_NAME,
+                            RELAY_COLOR_CHAT_CLIENT,
+                            client->desc,
+                            RELAY_COLOR_CHAT);
+        }
     }
 }
