@@ -1,5 +1,7 @@
 /*
- * Copyright (C) 2023-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2023-2025 Sébastien Helleu <flashcode@flashtux.org>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -38,6 +40,7 @@ enum t_relay_client_http_status
 #define RELAY_HTTP_401_UNAUTHORIZED           401, "Unauthorized"
 #define RELAY_HTTP_403_FORBIDDEN              403, "Forbidden"
 #define RELAY_HTTP_404_NOT_FOUND              404, "Not Found"
+#define RELAY_HTTP_405_METHOD_NOT_ALLOWED     405, "Method Not Allowed"
 #define RELAY_HTTP_500_INTERNAL_SERVER_ERROR  500, "Internal Server Error"
 #define RELAY_HTTP_503_SERVICE_UNAVAILABLE    503, "Service Unavailable"
 
@@ -51,6 +54,7 @@ enum t_relay_client_http_status
 #define RELAY_HTTP_ERROR_INVALID_ITERATIONS   "Invalid number of iterations"
 #define RELAY_HTTP_ERROR_BAD_REQUEST          "Bad request"
 #define RELAY_HTTP_ERROR_NOT_FOUND            "Resource not found"
+#define RELAY_HTTP_ERROR_METHOD_NOT_ALLOWED   "Method Not Allowed"
 #define RELAY_HTTP_ERROR_OUT_OF_MEMORY        "Out of memory"
 
 struct t_relay_http_request
@@ -96,7 +100,8 @@ extern long relay_http_get_param_long (struct t_relay_http_request *request,
 extern int relay_http_parse_method_path (struct t_relay_http_request *request,
                                          const char *method_path);
 extern int relay_http_check_auth (struct t_relay_client *client);
-extern void relay_http_recv (struct t_relay_client *client, const char *data);
+extern void relay_http_recv (struct t_relay_client *client,
+                             const char *data, int size);
 extern int relay_http_send (struct t_relay_client *client,
                             int return_code, const char *message,
                             const char *headers,
