@@ -1,7 +1,7 @@
 /*
- * script-command.c - script command
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Script command */
+
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
@@ -315,7 +317,7 @@ script_command_script (const void *pointer, void *data,
  */
 
 void
-script_command_init ()
+script_command_init (void)
 {
     weechat_hook_command (
         "script",
