@@ -1,7 +1,7 @@
 /*
- * script-mouse.c - mouse actions for script
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Mouse actions for script */
+
 #include <stdlib.h>
 #include <stdio.h>
 
@@ -39,6 +41,7 @@ script_mouse_focus_chat_cb (const void *pointer, void *data,
 {
     const char *buffer;
     int rc;
+    unsigned long value;
     struct t_gui_buffer *ptr_buffer;
     long x;
     char *error, str_date[64];
@@ -56,10 +59,12 @@ script_mouse_focus_chat_cb (const void *pointer, void *data,
     if (!buffer)
         return info;
 
-    rc = sscanf (buffer, "%p", &ptr_buffer);
+    rc = sscanf (buffer, "%lx", &value);
     if ((rc == EOF) || (rc == 0))
         return info;
 
+    ptr_buffer = (struct t_gui_buffer *)value;
+
     if (!ptr_buffer || (ptr_buffer != script_buffer))
         return info;
 
