@@ -1,7 +1,7 @@
 /*
- * trigger.c - trigger plugin for WeeChat
+ * SPDX-FileCopyrightText: 2014-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2014-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Trigger plugin for WeeChat */
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -698,11 +700,11 @@ trigger_regex_split (const char *str_regex,
 
         /* search the delimiter (which can be more than one char) */
         pos = weechat_utf8_next_char (ptr_regex);
-        while (pos[0] && (weechat_string_charcmp (ptr_regex, pos) == 0))
+        while (pos && pos[0] && (weechat_string_charcmp (ptr_regex, pos) == 0))
         {
             pos = weechat_utf8_next_char (pos);
         }
-        if (!pos[0])
+        if (!pos || !pos[0])
             goto format_error;
         delimiter = weechat_strndup (ptr_regex, pos - ptr_regex);
         if (!delimiter)
