@@ -1,7 +1,7 @@
 /*
- * xfer-network.c - network functions for xfer plugin
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Network functions for xfer plugin */
+
 #include <stdlib.h>
 #include <unistd.h>
 #include <errno.h>
@@ -26,6 +28,7 @@
 #include <stdint.h>
 #include <string.h>
 #include <fcntl.h>
+#include <sys/time.h>
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <sys/socket.h>
@@ -287,8 +290,8 @@ xfer_network_child_read_cb (const void *pointer, void *data, int fd)
                 {
                     /* connection was successful by child, init transfer times */
                     xfer->status = XFER_STATUS_ACTIVE;
-                    xfer->start_transfer = time (NULL);
-                    xfer->last_check_time = time (NULL);
+                    gettimeofday (&xfer->start_transfer, NULL);
+                    xfer->last_check_time = xfer->start_transfer;
                     xfer_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
                 }
                 else
@@ -571,7 +574,7 @@ xfer_network_fd_cb (const void *pointer, void *data, int fd)
             xfer_set_remote_address (xfer, (struct sockaddr *)&addr, length,
                                      str_address);
             xfer->status = XFER_STATUS_ACTIVE;
-            xfer->start_transfer = time (NULL);
+            gettimeofday (&xfer->start_transfer, NULL);
             xfer_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
             switch (xfer->type)
             {
