@@ -1,7 +1,7 @@
 /*
- * test-irc-info.cpp - test IRC info functions
+ * SPDX-FileCopyrightText: 2024-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2024-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,9 +19,11 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+/* Test IRC info functions */
+
 #include "CppUTest/TestHarness.h"
 
-#include "tests/tests.h"
+#include "tests.h"
 
 extern "C"
 {
