@@ -1,7 +1,7 @@
 /*
- * test-relay-remote-network.cpp - test network functions for relay remote
+ * SPDX-FileCopyrightText: 2024-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,9 +19,11 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+/* Test network functions for relay remote */
+
 #include "CppUTest/TestHarness.h"
 
-#include "tests/tests.h"
+#include "tests.h"
 
 extern "C"
 {
@@ -232,17 +234,16 @@ TEST(RelayRemoteNetwork, UrlHandshakeCb)
 
 TEST(RelayRemoteNetwork, GetHandshakeRequest)
 {
-    const char *str_start = "{\"password_hash_algo\": [\"";
     char *str;
-    int i;
 
-    str = relay_remote_network_get_handshake_request ();
-    CHECK(str);
-    STRNCMP_EQUAL(str_start, str, strlen (str_start));
-    for (i = 0; i < RELAY_NUM_PASSWORD_HASH_ALGOS; i++)
-    {
-        CHECK(strstr (str, relay_auth_password_hash_algo_name[i]));
-    }
+    WEE_TEST_STR("{\"password_hash_algo\":["
+                 "\"plain\","
+                 "\"sha256\","
+                 "\"sha512\","
+                 "\"pbkdf2+sha256\","
+                 "\"pbkdf2+sha512\""
+                 "]}",
+                 relay_remote_network_get_handshake_request ());
 }
 
 /*
