@@ -1,7 +1,7 @@
 /*
- * test-relay-api-protocol.cpp - test relay API protocol (protocol)
+ * SPDX-FileCopyrightText: 2024-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2024-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,9 +19,11 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+/* Test relay API protocol (protocol) */
+
 #include "CppUTest/TestHarness.h"
 
-#include "tests/tests-record.h"
+#include "tests-record.h"
 
 extern "C"
 {
@@ -319,14 +321,23 @@ TEST(RelayApiProtocolWithClient, CbHandshake)
     /* unknown password hash algorithm */
     test_client_recv_http ("POST /api/handshake", NULL,
                            "{\"password_hash_algo\": [\"invalid\"]}");
-    STRCMP_EQUAL("HTTP/1.1 200 OK\r\n"
+    STRCMP_EQUAL("HTTP/1.1 400 Bad Request\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 74\r\n"
+                 "Content-Length: 48\r\n"
                  "\r\n"
-                 "{\"password_hash_algo\":null,"
-                 "\"password_hash_iterations\":100000,"
-                 "\"totp\":false}",
+                 "{\"error\":\"Hash algorithm \\\"invalid\\\" not found\"}",
+                 data_sent[0]);
+
+    /* invalid password hash algorithm */
+    test_client_recv_http ("POST /api/handshake", NULL,
+                           "{\"password_hash_algo\": [{}]}");
+    STRCMP_EQUAL("HTTP/1.1 400 Bad Request\r\n"
+                 "Access-Control-Allow-Origin: *\r\n"
+                 "Content-Type: application/json; charset=utf-8\r\n"
+                 "Content-Length: 34\r\n"
+                 "\r\n"
+                 "{\"error\":\"Invalid hash algorithm\"}",
                  data_sent[0]);
 
     /* two supported hash algorithms */
@@ -962,7 +973,7 @@ TEST(RelayApiProtocolWithClient, RecvJson)
 TEST(RelayApiProtocolWithClient, RecvHttp404)
 {
     /* resource not found: error 404 */
-    test_client_recv_http ("GET / HTTP/1.1", NULL, NULL);
+    test_client_recv_http ("GET /", NULL, NULL);
     STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
@@ -972,7 +983,7 @@ TEST(RelayApiProtocolWithClient, RecvHttp404)
                  data_sent[0]);
 
     /* resource not found: error 404 */
-    test_client_recv_http ("GET /unknown HTTP/1.1", NULL, NULL);
+    test_client_recv_http ("GET /unknown", NULL, NULL);
     STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
@@ -982,7 +993,7 @@ TEST(RelayApiProtocolWithClient, RecvHttp404)
                  data_sent[0]);
 
     /* resource not found: error 404 */
-    test_client_recv_http ("GET /unknown/abc HTTP/1.1", NULL, NULL);
+    test_client_recv_http ("GET /unknown/abc", NULL, NULL);
     STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
@@ -992,7 +1003,7 @@ TEST(RelayApiProtocolWithClient, RecvHttp404)
                  data_sent[0]);
 
     /* resource not found: error 404 */
-    test_client_recv_http ("GET /api HTTP/1.1", NULL, NULL);
+    test_client_recv_http ("GET /api", NULL, NULL);
     STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
@@ -1002,7 +1013,7 @@ TEST(RelayApiProtocolWithClient, RecvHttp404)
                  data_sent[0]);
 
     /* resource not found: error 404 */
-    test_client_recv_http ("GET /api/unknown HTTP/1.1", NULL, NULL);
+    test_client_recv_http ("GET /api/unknown", NULL, NULL);
     STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
@@ -1020,7 +1031,7 @@ TEST(RelayApiProtocolWithClient, RecvHttp404)
 TEST(RelayApiProtocolWithClient, RecvHttpMissingPassword)
 {
     /* unauthorized: missing password */
-    test_client_recv_http_raw ("GET /api/version HTTP/1.1\r\n"
+    test_client_recv_http_raw ("GET /api/version\r\n"
                                "\r\n");
     STRCMP_EQUAL("HTTP/1.1 401 Unauthorized\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
@@ -1039,7 +1050,7 @@ TEST(RelayApiProtocolWithClient, RecvHttpMissingPassword)
 TEST(RelayApiProtocolWithClient, RecvHttpInvalidPassword)
 {
     /* unauthorized: invalid password: "plain:invalid" */
-    test_client_recv_http_raw ("GET /api/version HTTP/1.1\r\n"
+    test_client_recv_http_raw ("GET /api/version\r\n"
                                "Authorization: Basic cGxhaW46aW52YWxpZA==\r\n"
                                "\r\n");
     STRCMP_EQUAL("HTTP/1.1 401 Unauthorized\r\n"
@@ -1050,3 +1061,44 @@ TEST(RelayApiProtocolWithClient, RecvHttpInvalidPassword)
                  "{\"error\":\"Invalid password\"}",
                  data_sent[0]);
 }
+
+/*
+ * Tests functions:
+ *   relay_api_protocol_recv_http (method not allowed)
+ */
+
+TEST(RelayApiProtocolWithClient, RecvHttpMethodNotAllowed)
+{
+    /* method not allowed (PATCH) with existing resource (/api/ping) */
+    test_client_recv_http ("PATCH /api/ping", NULL, "{\"data\": \"abcdef\"}");
+    STRCMP_EQUAL("HTTP/1.1 405 Method Not Allowed\r\n"
+                 "Allow: GET, POST, PUT, DELETE\r\n"
+                 "Access-Control-Allow-Origin: *\r\n"
+                 "Content-Type: application/json; charset=utf-8\r\n"
+                 "Content-Length: 30\r\n"
+                 "\r\n"
+                 "{\"error\":\"Method Not Allowed\"}",
+                 data_sent[0]);
+
+    /* method not allowed (PATCH) with unknown resource (/api/unknown) */
+    test_client_recv_http ("PATCH /api/unknown", NULL, "{\"data\": \"abcdef\"}");
+    STRCMP_EQUAL("HTTP/1.1 405 Method Not Allowed\r\n"
+                 "Allow: GET, POST, PUT, DELETE\r\n"
+                 "Access-Control-Allow-Origin: *\r\n"
+                 "Content-Type: application/json; charset=utf-8\r\n"
+                 "Content-Length: 30\r\n"
+                 "\r\n"
+                 "{\"error\":\"Method Not Allowed\"}",
+                 data_sent[0]);
+
+    /* method not allowed (PATCH) with unknown resource (/unknown) */
+    test_client_recv_http ("PATCH /unknown", NULL, "{\"data\": \"abcdef\"}");
+    STRCMP_EQUAL("HTTP/1.1 405 Method Not Allowed\r\n"
+                 "Allow: GET, POST, PUT, DELETE\r\n"
+                 "Access-Control-Allow-Origin: *\r\n"
+                 "Content-Type: application/json; charset=utf-8\r\n"
+                 "Content-Length: 30\r\n"
+                 "\r\n"
+                 "{\"error\":\"Method Not Allowed\"}",
+                 data_sent[0]);
+}
