@@ -1,6 +1,8 @@
 #!/bin/sh
 #
-# Copyright (C) 2014-2024 Sébastien Helleu <flashcode@flashtux.org>
+# SPDX-FileCopyrightText: 2014-2025 Sébastien Helleu <flashcode@flashtux.org>
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
 # This file is part of WeeChat, the extensible chat client.
 #
@@ -20,10 +22,11 @@
 
 #
 # Build WeeChat according to environment variables:
-#   - BUILDARGS: arguments for cmake command
+#   - JOBS: number of parallel jobs
+#   - RUN_TESTS: set to 0 to disable run of tests
 #
 # Syntax to run the script with environment variables:
-#   BUILDARGS="arguments" ./build_test.sh
+#   RUN_TESTS=0 JOBS=2 ./build_test.sh
 #
 # Syntax to run the script with arguments on command line:
 #   ./build_test.sh [arguments]
@@ -33,30 +36,27 @@
 
 set -o errexit
 
-build_dir="build-tmp-$$"
-
-if [ $# -ge 1 ]; then
-    BUILDARGS="$*"
-fi
-
-run ()
-{
-    "$@"
-}
-
 # display commands
 set -x
 
+build_dir="build-tmp-$$"
+
 # create build directory
 mkdir "${build_dir}"
 cd "${build_dir}"
 
-run cmake .. -DENABLE_MAN=ON -DENABLE_DOC=ON -DENABLE_TESTS=ON "${BUILDARGS}"
+if [ -z "${JOBS}" ]; then
+    JOBS="$(nproc)"
+fi
+
+cmake .. "$@"
 if [ -f "build.ninja" ]; then
     ninja -v
     sudo ninja install
 else
-    make VERBOSE=1 -j "$(nproc)"
+    make VERBOSE=1 -j "${JOBS}"
     sudo make install
 fi
-ctest -V
+if [ "$RUN_TESTS" != "0" ]; then
+    ctest -V
+fi
